// $Id: Jupiter.cc,v 1.1.1.1 2001/06/08 15:38:38 hoshina Exp $
// ====================================================================
//    Jupiter.cc
//   
//    Exapmle program provided by JLC-CDC group.
//
//    NOTE:
//    Please contact me(hoshina@jlcux1.kek.jp) if any problems 
//    or questions. DO NOT bother Geant4 developpers and Geant4 Users
//    Group Japan.
//
//                                K.Hoshina , 2001
// ====================================================================
#include "G4RunManager.hh"
#include "G4UIterminal.hh"
#include "G4UItcsh.hh"

#include "J4DetectorConstruction.hh"
#include "J4PhysicsList.hh"
#include "J4PrimaryGeneratorAction.hh"
#include "J4RunAction.hh"
#include "J4EventAction.hh"

#ifdef G4VIS_USE
#include "J4VisManager.hh"
#endif

//#include "CLHEP/Random/Random.h"

// ====================================================================
//     main
// ====================================================================
int main(int argc, char** argv) 
{
  // if you want to change a random engine, for example, ...
  //HepJamesRandom randomEngine;
  //RanecuEngine randomEngine;
  //HepRandom::setTheEngine(&randomEngine);

  // run manager
  G4RunManager* runManager= new G4RunManager;  G4cout << endl;

  // set mandatory user initialization classes...
  // detector setup
  runManager-> SetUserInitialization(new J4DetectorConstruction);
  // particles and physics processes
  runManager-> SetUserInitialization(new J4PhysicsList);

  // set mandatory user action class...
  // primary generator
  runManager-> SetUserAction(new J4PrimaryGeneratorAction);

  // user action classes... (optional)
  runManager-> SetUserAction(new J4RunAction);
  runManager-> SetUserAction(new J4EventAction);

#ifdef G4VIS_USE
  // initialize visualization package
  G4VisManager* visManager= new J4VisManager;
  visManager-> Initialize();
  G4cout << endl;
#endif

  // user session...
  runManager-> Initialize();
    
  if(argc==1) { // interactive session, if no arguments given
#ifdef USE_CSH_TERMINAL    
    // csh-like
    G4UIterminal* session= new G4UIterminal();
    session-> SetPrompt("G4test(%s)[%/]:");
#else
    // tcsh-like
    G4UItcsh* tcsh= new 
      G4UItcsh("[36mexU01[33m(%s)[32m[%/][36m[%h][37m:");
    G4UIterminal* session= new G4UIterminal(tcsh);
    tcsh-> SetLsColor(GREEN, CYAN);
#endif
    session-> SessionStart();
    delete session;

  } else { // batch mode
    G4UImanager* UImanager= G4UImanager::GetUIpointer();
    G4String command = "/control/execute ";
    G4String fileName = argv[1];
    UImanager-> ApplyCommand(command+fileName);
  }

  // terminating...
#ifdef G4VIS_USE
  delete visManager;
#endif

  delete runManager;  G4cout << endl;
  return 0;
}

