// $Id: J4CDCSenseWire.cc,v 1.1.1.1 2001/06/08 15:38:43 hoshina Exp $
//*************************************************************************
//* --------------------
//* J4CDCSenseWire
//* --------------------
//* (Description)
//* 	Class for describing his/her detector compornents.
//*     
//* (Update Record)
//*	2000/12/08  K.Hoshina	Original version.
//*************************************************************************

#include "J4CDCSenseWire.hh"
#include "J4CDCSenseWireSD.hh"

#include "G4Tubs.hh"
#include "G4RotationMatrix.hh"

// ====================================================================
//--------------------------------
// constants (detector parameters)
//--------------------------------

G4String J4CDCSenseWire::fName("SenseWire");


//=====================================================================
//---------------------
// Class Description
//---------------------

//* constructor -------------------------------------------------------
J4CDCSenseWire::J4CDCSenseWire(J4VDetectorComponent *parent,
			       G4int nclones,
  		  	       G4int nbrothers, 
  		  	       G4int me ) :
  		J4VCDCDetectorComponent( fName, parent, nclones, 
  					 nbrothers, me  )
{   
}

//* destructor --------------------------------------------------------
J4CDCSenseWire::~J4CDCSenseWire()
{	
}

//* Assemble   --------------------------------------------------------
void J4CDCSenseWire::Assemble()
{
  if(!GetLV())
  {
  		
   // define parameter
   
    G4double len  = 
        ((G4Tubs *)GetMother()->GetLV()->GetSolid())->GetZHalfLength();
    G4double rmin = _CDCSenseWireIR_;
    G4double rmax = _CDCSenseWireOR_;
        
   // Asssemble LogicalVolume...
        
    OrderNewTubs (rmin, rmax, len );		  	  // MakeSolid
    
    MakeLVWith (OpenMaterialStore()->Order(_CDCSENSEWIREMATERIAL_));
    							  // Define LV
    
    PaintLV (_CDCSenseWireVisAtt_, G4Color(1.,0.,1.));	  // Set VisAttribute

  }
}

//* Cabling  ----------------------------------------------------------

void J4CDCSenseWire::Cabling()
{
  if(!GetLV()) Assemble(); 

  J4CDCSenseWireSD* sd = new J4CDCSenseWireSD(this);
  SetSD(sd);
}

//* InstallIn  --------------------------------------------------------

void J4CDCSenseWire::InstallIn(J4VDetectorComponent* mother)
{
	
 //* Assemble its LogicalVolume...	 
  
  Assemble();		// You MUST call Assemble(); at first.
  
 //* Install the SenseWire in a DriftRegion...	 
    	
  G4LogicalVolume* motherLV = mother->GetLV();
    
  G4LogicalVolume* lv = GetLV();		// Get SenseWire_LV
  
  G4double motherIR   = ((G4Tubs *)motherLV->GetSolid())->GetInnerRadius();
  G4double motherOR   = ((G4Tubs *)motherLV->GetSolid())->GetOuterRadius();
  G4double motherSphi = ((G4Tubs *)motherLV->GetSolid())->GetStartPhiAngle();
  G4double motherDphi = ((G4Tubs *)motherLV->GetSolid())->GetDeltaPhiAngle();
    
  G4double          x    = (motherIR + motherOR)/2.0 ;  

#if 1  
  G4ThreeVector tlate(x, 0., 0.);
#else
  G4ThreeVector tlate(0., 0., 0.);
#endif

  SetPVPlacement(0, tlate);
  
//      G4cerr << " My name is " << GetName().data() << G4endl;


#if 1

  SwitchOff();

#endif
      
}


//* SwitchOn  --------------------------------------------------------
void J4CDCSenseWire::SwitchOn()
{
  SetIsOn(TRUE);
  Cabling();
}

//* SwitchOff  --------------------------------------------------------
void J4CDCSenseWire::SwitchOff()
{
  SetIsOn(FALSE);
  Cabling();
}

//* Draw  --------------------------------------------------------
void J4CDCSenseWire::Draw()
{
  // set visualization attributes
  
}
	
//* Print  --------------------------------------------------------
void J4CDCSenseWire::Print() const
{
}

	
	
