// $Id: J4DetectorConstruction.cc,v 1.1.1.1 2001/06/08 15:38:43 hoshina Exp $
//*************************************************************************
//* --------------------------
//* J4DetectorConstruction.cc
//* --------------------------
//* (Description)
//* 	
//*     
//* (Update Record)
//*	2000/12/08  K.Hoshina	Original version.
//*************************************************************************


#include "J4DetectorConstruction.hh"
#include "J4ExpHall.hh"
#include "J4MagneticField.hh"

#include "G4FieldManager.hh"
#include "G4TransportationManager.hh"
#include "G4ChordFinder.hh"


J4ExpHall* J4DetectorConstruction::fExpHall = 0; 

//************************************************************************
//---------------------
// Class Description
//---------------------
 
//=====================================================================
//* constructor -------------------------------------------------------

J4DetectorConstruction::J4DetectorConstruction()
			:fBeampipe(0), fVTX(0), fIT(0), fCDC(0),fCAL(0) 
{
}

//=====================================================================
//* destructor --------------------------------------------------------

J4DetectorConstruction::~J4DetectorConstruction()
{
#if 0  
  if (fExpHall) delete fExpHall;
  if (fBeampipe)delete fBeampipe;
  if (fVTX)     delete fVTX;
  if (fCDC)     delete fCDC;
#endif  
}

//=====================================================================
//* Construct   -------------------------------------------------------

G4VPhysicalVolume* J4DetectorConstruction::Construct()
{
  
  //---------------------------
  // Experimental Hall (world)
  //---------------------------

    fExpHall  = new J4ExpHall(0, 1, 1, 0);
    
#if 1    
    
  //---------------------------
  // Beam pipe 
  //---------------------------
  
    fBeampipe = new J4Beampipe(fExpHall, 1, 1, 0 );
    fBeampipe->InstallIn(fExpHall);
    fExpHall->SetDaughter(fBeampipe);

  // ---------------------------
  // each detector component
  // ---------------------------
  
#if 1
    fVTX = new J4VTX(fExpHall, 1, 1, 0 );
    fVTX->InstallIn(fExpHall);
    fExpHall->SetDaughter(fVTX);
#endif
#if 1
    fIT = new J4IT(fExpHall, 1, 1, 0 );
    fIT->InstallIn(fExpHall);
    fExpHall->SetDaughter(fIT);
#endif

#if 1
    fCDC = new J4CDC(fExpHall, 1, 1, 0 );
    fCDC->InstallIn(fExpHall);
    fExpHall->SetDaughter(fCDC);
#endif
#if 1
    fCAL = new J4CAL(fExpHall, 1, 1, 0 );
    fCAL->InstallIn(fExpHall);
    fExpHall->SetDaughter(fCAL);
#endif

#endif
    
  // ---------------------------
  // magnetic field
  // ---------------------------
  
    G4FieldManager* fieldManager= 
      G4TransportationManager::GetTransportationManager()-> GetFieldManager();

    J4MagneticField* magField= new J4MagneticField;
    fieldManager-> SetDetectorField(magField);
    fieldManager-> CreateChordFinder(magField);
    fieldManager-> GetChordFinder()-> SetDeltaChord(1.*mm);  // if you need
  
  // ==============================================================
  // return PV of the world volume
  return fExpHall->GetPV();
}

