// $Id: J4VTX.cc,v 1.1.1.1 2001/06/08 15:38:44 hoshina Exp $
//*************************************************************************
//* --------------------
//* J4VTX
//* --------------------
//* (Description)
//* 	Class for describing his/her detector compornents.
//*     
//* (Update Record)
//*	2000/12/08  K.Hoshina	Original version.
//*************************************************************************

#include "J4VTX.hh"


// ====================================================================
//--------------------------------
// constants (detector parameters)
//--------------------------------

G4String J4VTX::fName("VTX");

//=====================================================================
//---------------------
// Class Description
//---------------------

//=====================================================================
//* constructor -------------------------------------------------------

J4VTX::J4VTX(J4VDetectorComponent *parent,
			    G4int nclones,
  		  	    G4int nbrothers, 
  		  	    G4int me ) :
  		J4VVTXDetectorComponent( fName, parent, nclones,
  					 nbrothers, me  ) 
{   
}

//=====================================================================
//* destructor --------------------------------------------------------

J4VTX::~J4VTX()
{
	
  if (fLayers){	
    G4int i;  
    for (i = 0; i < _VTXLAYERNLAYERS_ ; i++) {
     if(fLayers[i]) delete fLayers [i];
    } 
    delete [] fLayers;
  }
}

//=====================================================================
//* Assemble   --------------------------------------------------------

void J4VTX::Assemble() 
{   
  if(!GetLV()){
  	
    G4double rmin = _VTXIR_;
    G4double rmax = _VTXOR_;
    G4double len  = _VTXLEN_;
    G4double dphi = _VTXDPHI_;
  	
    // MakeSolid ----------//
    OrderNewTubs (rmin, rmax, len, dphi);
    
    // MakeLogicalVolume --//  
    MakeLVWith(OpenMaterialStore()->Order(_VTXMATERIAL_));
    
    // SetVisAttribute ----//
    PaintLV(_VTXVISATT_, G4Color(1, 0, 1));
  	
    // Install daughter PV //
    // Install Layer       //
  		  
    fLayers = new J4VTXLayer* [_VTXLAYERNLAYERS_];
    G4int i;  
    for (i = 0; i < _VTXLAYERNLAYERS_ ; i++) {
      fLayers [i] = new J4VTXLayer(this,_VTXLAYERNCLONES_ , _VTXLAYERNLAYERS_ , i );
      fLayers [i]->InstallIn(this);  
      
      SetDaughter(fLayers[i]);
    }  
      
  }
}

//=====================================================================
//* Cabling  ----------------------------------------------------------

void J4VTX::Cabling()
{
}

//=====================================================================
//* InstallIn  --------------------------------------------------------

void J4VTX::InstallIn(J4VDetectorComponent* mother)
{ 
  Assemble();			// You MUST call Assemble(); at first.
  				// 
  
  // Placement function into mother object...
  
  SetPVPlacement();
  
}


//* SwitchOn  --------------------------------------------------------
void J4VTX::SwitchOn()
{
}

//* SwitchOff  --------------------------------------------------------
void J4VTX::SwitchOff()
{
}

//* Draw  --------------------------------------------------------
void J4VTX::Draw()
{
  // set visualization attributes
  
}
	
//* Print  --------------------------------------------------------
void J4VTX::Print() const
{
}

	
	
